@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.texttospeech import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from google.cloud.texttospeech_v1.services.text_to_speech.async_client import (
     TextToSpeechAsyncClient,
@@ -20,6 +24,12 @@ from google.cloud.texttospeech_v1.services.text_to_speech.async_client import (
 from google.cloud.texttospeech_v1.services.text_to_speech.client import (
     TextToSpeechClient,
 )
+from google.cloud.texttospeech_v1.services.text_to_speech_long_audio_synthesize.async_client import (
+    TextToSpeechLongAudioSynthesizeAsyncClient,
+)
+from google.cloud.texttospeech_v1.services.text_to_speech_long_audio_synthesize.client import (
+    TextToSpeechLongAudioSynthesizeClient,
+)
 from google.cloud.texttospeech_v1.types.cloud_tts import (
     AudioConfig,
     AudioEncoding,
@@ -33,10 +43,17 @@ from google.cloud.texttospeech_v1.types.cloud_tts import (
     Voice,
     VoiceSelectionParams,
 )
+from google.cloud.texttospeech_v1.types.cloud_tts_lrs import (
+    SynthesizeLongAudioMetadata,
+    SynthesizeLongAudioRequest,
+    SynthesizeLongAudioResponse,
+)
 
 __all__ = (
     "TextToSpeechClient",
     "TextToSpeechAsyncClient",
+    "TextToSpeechLongAudioSynthesizeClient",
+    "TextToSpeechLongAudioSynthesizeAsyncClient",
     "AudioConfig",
     "CustomVoiceParams",
     "ListVoicesRequest",
@@ -48,4 +65,7 @@ __all__ = (
     "VoiceSelectionParams",
     "AudioEncoding",
     "SsmlVoiceGender",
+    "SynthesizeLongAudioMetadata",
+    "SynthesizeLongAudioRequest",
+    "SynthesizeLongAudioResponse",
 )
