@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from .client import TextToSpeechClient
 from .async_client import TextToSpeechAsyncClient
+from .client import TextToSpeechClient
 
-__all__ = ("TextToSpeechClient", "TextToSpeechAsyncClient")
+__all__ = (
+    "TextToSpeechClient",
+    "TextToSpeechAsyncClient",
+)
