@@ -13,8 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.texttospeech import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.text_to_speech import TextToSpeechAsyncClient, TextToSpeechClient
+from .services.text_to_speech_long_audio_synthesize import (
+    TextToSpeechLongAudioSynthesizeAsyncClient,
+    TextToSpeechLongAudioSynthesizeClient,
+)
 from .types.cloud_tts import (
     AudioConfig,
     AudioEncoding,
@@ -29,9 +37,15 @@ from .types.cloud_tts import (
     Voice,
     VoiceSelectionParams,
 )
+from .types.cloud_tts_lrs import (
+    SynthesizeLongAudioMetadata,
+    SynthesizeLongAudioRequest,
+    SynthesizeLongAudioResponse,
+)
 
 __all__ = (
     "TextToSpeechAsyncClient",
+    "TextToSpeechLongAudioSynthesizeAsyncClient",
     "AudioConfig",
     "AudioEncoding",
     "CustomVoiceParams",
@@ -39,9 +53,13 @@ __all__ = (
     "ListVoicesResponse",
     "SsmlVoiceGender",
     "SynthesisInput",
+    "SynthesizeLongAudioMetadata",
+    "SynthesizeLongAudioRequest",
+    "SynthesizeLongAudioResponse",
     "SynthesizeSpeechRequest",
     "SynthesizeSpeechResponse",
     "TextToSpeechClient",
+    "TextToSpeechLongAudioSynthesizeClient",
     "Timepoint",
     "Voice",
     "VoiceSelectionParams",
